@@ -6,7 +6,7 @@ use Carp qw(croak);
 use Math::DifferenceSet::Planar::Data;
 use Math::BigInt try => 'GMP';
 use Math::Prime::Util qw(
-    is_power is_prime_power euler_phi factor gcd
+    is_power is_prime_power euler_phi factor_exp gcd
     mulmod addmod invmod powmod
 );
 
@@ -24,7 +24,7 @@ use constant _F_PEAK      =>  8;    # peak elements arrayref, initially undef
 use constant _F_ETA       =>  9;    # "eta" value, initially undef
 use constant _NFIELDS     => 10;
 
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 
 our $_LOG_MAX_ORDER  = 22.1807;         # limit for integer exponentiation
 our $_MAX_ENUM_COUNT = 32768;           # limit for stored rotator set size
@@ -137,7 +137,7 @@ sub _sequential_rotators {
         @{$this}[_F_BASE, _F_EXPONENT, _F_MODULUS, _F_N_PLANES];
     my @mult = _multipliers($base, $exponent, $modulus);
     shift @mult;
-    my @pf = factor($modulus);
+    my @pf = map { $_->[0] } factor_exp($modulus);
     pop @pf if $pf[-1] == $modulus;
     my $mx = 0;
     my $x  = 0;
@@ -649,7 +649,7 @@ Math::DifferenceSet::Planar - object class for planar difference sets
 
 =head1 VERSION
 
-This documentation refers to version 0.014 of Math::DifferenceSet::Planar.
+This documentation refers to version 0.015 of Math::DifferenceSet::Planar.
 
 =head1 SYNOPSIS
 
